#
# spec file for package tidy
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define regression_tests 97cf741
%define documentation    c0d1cd1

Name:           tidy
Version:        5.4.0
Release:        lp151.3.3.1
Summary:        Utility to Clean Up and Pretty-print HTML, XHTML or XML Markup
License:        W3C
Group:          Productivity/Publishing/HTML/Tools
Url:            https://github.com/htacg/tidy-html5
Source0:        https://github.com/htacg/tidy-html5/archive/%{version}.tar.gz
# Latest version of unit tests
Source1:        https://github.com/htacg/tidy-html5-tests/archive/%{regression_tests}.tar.gz
# Documentation generation files, extracted from
#   https://github.com/htacg/html-tidy.org.api.git/archive/%%{documentation}.tar.gz
# using tidy_generate_documentation.sh
Source2:        tidy-html5-doxygen-%{documentation}.tar.gz
Source10:       tidy_fetch_docs.sh
Patch0:         dynamic_library_build.diff
Patch1:         test_fixes.diff
Patch2:         fix_doxygen_paths.diff
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tidy is a commandline frontend to TidyLib which allows for cleaning up and
pretty printing HTML, XHTML and XML markup in a variety of file encodings. For
HTML variants, it can detect and report proprietary elements as well as many
common coding errors, correct them and produce visually equivalent markup
which is both compliant with W3C standards and works on most browsers.
Furthermore, it can convert plain HTML to XHTML. For generic XML files, Tidy is
limited to correcting basic well-formedness errors and pretty printing.

%package doc
Summary:        Documentation for tidy and libtidy5
Group:          Productivity/Publishing/HTML/Tools
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
This package contains the documentation for both tidy and libtidy.

%package -n libtidy5
Summary:        Library to Clean Up and Pretty-print HTML, XHTML or XML Markup
Group:          Productivity/Publishing/HTML/Tools
Provides:       libtidy = %{version}
Obsoletes:      libtidy <= 1.0

%description -n libtidy5
TidyLib is a library for cleaning up and pretty printing HTML, XHTML and XML
markup in a variety of file encodings. For HTML variants, it can detect and
report proprietary elements as well as many common coding errors, correct them
and produce visually equivalent markup which is both compliant with W3C
standards and works on most browsers. Furthermore, it can convert plain HTML
into XHTML. For generic XML files, Tidy is limited to correcting basic
well-formedness errors and pretty printing.

There is a commandline frontend for this library, contained in the package
"tidy".

%package -n libtidy-devel
Summary:        Include Files and Libraries for Development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libtidy5 = %{version}
Obsoletes:      libtidy-0_99-0-devel
Conflicts:      libtidy-0_99-0-devel
Conflicts:      tidy-html5-devel

%description -n libtidy-devel
This package contains all necessary include files and libraries needed
to develop applications using functions provided by the TidyLib library.

%prep
%setup -q -a 1 -a 2 -n tidy-html5-%{version}
mv tidy-html5-tests-* tests
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%cmake \
    -DCMAKE_SKIP_RPATH:BOOL=OFF \
    -DINCLUDE_INSTALL_DIR:PATH=include/%{name} \
    -DTIDY_COMPAT_HEADERS:BOOL=ON
make %{?_smp_mflags}
../tidy-html5-doxygen/build_docs.sh

%install
%cmake_install

%post -n libtidy5 -p /sbin/ldconfig

%postun -n libtidy5 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%{_bindir}/tidy
%{_mandir}/man1/tidy.1*

%files -n tidy-doc
%defattr(-, root, root)
%doc build/docs/api/

%files -n libtidy5
%defattr(-, root, root)
%{_libdir}/libtidy*.so.*

%files -n libtidy-devel
%defattr(-, root, root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/tidy.h
%{_includedir}/%{name}/tidybuffio.h
%{_includedir}/%{name}/tidyenum.h
%{_includedir}/%{name}/tidyplatform.h
%{_includedir}/%{name}/buffio.h
%{_includedir}/%{name}/platform.h
%{_libdir}/libtidy.so

%changelog
* Fri May  5 2017 adam.majer@suse.de
- actually enable and distribute compat headers
- explicitly list headers instead of globing so nothing
  "disappears" with version updates
* Mon Apr 10 2017 adam.majer@suse.de
- new upstream version 5.4.0
- compat_headers.diff: upstreamed
- static_buffer_overflow.diff: upstreamed
- updated documentation to current
  +  tidy-html5-doxygen-a8e47dc.tar.gz replaced by
    tidy-html5-doxygen-c0d1cd1.tar.gz
- updated unit tests to current
  + a510b54.tar.gz replaced by 97cf741.tar.gz
- fix_doxygen_paths.diff: refreshed
- test_fixes.diff: refreshed
* Thu Aug  4 2016 adam.majer@suse.de
- add static_buffer_overflow.diff:
  + fix overflow in a static buffer (CVE-2016-6583)
- add Debian package files form fomer tidy-html5 packagee
  these don't really work, but mostly as WIP
* Thu Jun  2 2016 adam.majer@suse.de
- new upstream version 5.2.0
  + added support for HTML5
- new upstream authors at https://github.com/htacg/tidy-html5
- remove tidy_generate_tarball.sh
  + not needed
- remove tidy-fix-buffer-overflow.patch
  + upstreamed
- add fix_doxygen_paths.diff
  + patch Doxygen config file to build documentation from buld
    directory
- add test_fixes.diff
  + fix build paths
  + remove pauses via `read` bash builtin
  + don't hide logging in log files
- add dynamic_library_build.diff
  + use standard cmake BUILD_SHARED_LIBS instead of BUILD_SHARED_LIB
  + build both static and dynamic libraries by default, instead
    of just static
  + link vs. dynamic by default
- add tidy_fetch_docs.sh
  + used to fetch latest documentation configuration sources
- add compat_headers.diff
  + upstream changed some header names, so provide compatible header
    wrappers with a compile time warning
- change library subpackage according to new soname
- build libtidy-devel instead of having soname in devel package name
* Thu Jul 16 2015 astieger@suse.com
- add CVE to previous changelog entry
* Thu Jun  4 2015 gber@opensuse.org
- add tidy-fix-buffer-overflow.patch in order to fix a heap-based
  buffer overflow in tidy/libtidy (gh#htacg/tidy-html5#217
  boo#933588) CVE-2015-5522 CVE-2015-5523
* Mon Jun 18 2012 cfarrell@suse.com
- license update: W3C
  SPDX format (the license corresponds to the W3C Software License)
* Mon Feb 15 2010 guido+opensuse.org@berhoerster.name
- fix libtidy-0_99-0-devel not providing/obsoleting libtidy-devel
* Thu Feb  4 2010 guido+opensuse.org@berhoerster.name
- updated to CVS snapshot 20100202
- cleaned up
  * included script to generate a tarball from CVS
  * consistent usage of license tag
  * removed erroneously packaged files
  * more concise description conforming to packaging policy
  * lint clean
  * renamed libtidy(-devel) to libtidy-0_99-0(-devel)
  * removed trailing period from libtidy-dev summary
  * split documentation into tidy-doc subpackage
* Sun Feb 22 2009 crrodriguez@suse.de
- remove static libraries
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Mon Nov 13 2006 ro@suse.de
- added directory to filelist
* Mon Nov 13 2006 poeml@suse.de
- copying package from buildservice package to autobuild
  (adding .changes file)
* Mon Oct 23 2006 sierkb@gmx.de
- Updated tidy from CVS snapshot 061023.
* Thu Oct  5 2006 sierkb@gmx.de
- Updated tidy from CVS snapshot 061006.
* Mon Sep 18 2006 sierkb@gmx.de
- Updated tidy from CVS snapshot 060919.
* Wed Jun 14 2006 sierkb@gmx.de
- Rebuild for SUSE Linux 10.1
* Tue Feb 21 2006 sierkb@gmx.de
- Updated tidy from CVS snapshot 060222.
- Spec file clean-ups:
  - Removed libmxl2 from BuildRequires.
  - Removed authors due to anti-spam strategy.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 28 2005 sierkb@gmx.de
- Generating also a debug information sub-package.
* Tue Nov 22 2005 sierkb@gmx.de
- Rebuild for SUSE Linux 10.0 OSS (GCC 4.0.2)
* Mon Oct 31 2005 sierkb@gmx.de
- Updated tidy to 051027.
- Updated docs to 051021.
* Wed Oct 26 2005 sierkb@gmx.de
- New destination for tidy's header files: /usr/include/tidy rather than /usr/include.
- Spec file clean-up.
* Sun Oct 16 2005 sierkb@gmx.de
- Updated tidy to 051014.
* Tue Sep 27 2005 sierkb@gmx.de
- Removed extra patch for fixing casting issue,
  because the issue now is fixed.
* Wed Sep 21 2005 sierkb@gmx.de
- To reflect the fact that the Quick Reference and the Manpage can be autogenerated
  through the Tidy Makefile, all instructions to reproduce this manually
  now are removed from the Spec file and are replaced by the much shorter equivalent
  'make doc'.
* Mon Sep 19 2005 sierkb@gmx.de
- Updated tidy to 050913.
- Updated docs to 050706.
* Fri Jul 22 2005 sierkb@gmx.de
- Updated tidy to 050723.
* Wed Jun 22 2005 sierkb@gmx.de
- Updated tidy to 050623.
* Wed Jun 22 2005 sierkb@gmx.de
- Fixed casting issue, by Marcus Meissner.
- Adjusted authors list to tidy's project member list on Sourceforge.net.
* Mon Jun 20 2005 sierkb@gmx.de
- Corrected prep options.
* Thu Jun 16 2005 sierkb@gmx.de
- Updated tidy to 050616.
- Updated docs to 050616.
- Corrected version number to 1.0.
* Mon Jun  6 2005 sierkb@gmx.de
- Added license to libtidy package.
- Improved Spec file according to the SUSE Package conventions.
* Thu Jun  2 2005 sierkb@gmx.de
- Cleaned up spec file;
  fixed some email addresses;
  corrected version number.
- Build with RPM_OPT_FLAGS.
* Tue May 31 2005 poeml@suse.de
- improve generation and installation of documentation
  (thanks to Sierk Bornemann who provided key assistance)
* Mon May 30 2005 poeml@suse.de
- split libtidy subpackage, and rename tidy-devel to libtidy-devel
- install missing documentation
- run ldconfig in %%post/%%postun where needed
* Fri May 27 2005 sierkb@gmx.de
- Updated docs to 050503.
- Create and install Quickref and man page (manually because the gnuauto
  Makefile doesn't do it yet).
* Thu May 26 2005 poeml@suse.de
- update to version 050517 + docs to 050502
- use gnuauto buildsystem to get the shared lib
- create and install man page (manually because the gnuauto
  Makefile doesn't do it yet)
- package the license
- split -devel subpackage
* Wed May 25 2005 sierkb@gmx.de
- Updated tidy to 050518 and docs to 050311.
- Initial build for SuSE Linux.
* Thu May 12 2005 ke@suse.de
- Update to version 050502.
- Add htmldoc.tgz (from tidy CVS).
- Remove obsolete files, which are now part of htmldoc.tgz.
- Install tab2space.
- Fix casting issue, by Marcus Meissner.
* Tue May 10 2005 meissner@suse.de
- build with RPM_OPT_FLAGS.
* Thu Feb 26 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Mon Jun 16 2003 coolo@suse.de
- use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Apr 29 2002 drahn@suse.de
- update to: tidy version 020428
* Mon Dec  4 2000 mge@suse.de
- update to: tidy4aug00
* Tue Jun 27 2000 mge@suse.de
- update to: tidy30apr00
* Thu Jan 27 2000 ke@suse.de
- update to version 13jan00.
- translate the version string to make the update process happy.
- define version _after_ the Version header line.
- use the %%{version} and %%{name} macro.
- use %%{_mandir}.
- add a nice group tag.
- add %%defattr to the %%files section.
- Overview.html: use an sed trick to resolve remote references: insert the
  <base> element.
* Mon Oct 25 1999 mge@suse.de
- initial SuSE-RPM; Changed Overview.html to work "offline".
